v_scroller library

Classes

ValueSelectorVelocity
A velocity-aware value selector using 0.5 unit steps and scroll physics that scale user scrolling based on velocity. Does not replace existing selector yet.
VelocityScaledFixedExtentPhysics
ScrollPhysics that scale the user offset and fling velocity based on how fast the finger/scroll is moving; designed for fixed-extent lists (step=1).
VScrollerStyle
Styling configuration for the scroller widgets. Provides sensible defaults but is fully overrideable by consumers of the package.